########################################################################

# Analysis for toad movement data

########################################################################

#Load packages
library(lattice)
library(ggplot2)
library(dplyr)
library(lme4)
library(lmerTest)
library(MuMIn)
library(car)
library(sjPlot)
library(sjmisc)
library(sjlabelled)
library(devtools)
library(ggbiplot)
library(ggplot2)
library(grid)
######################################

#Import the file into a dataframe
# All data
toad <- read.table(file = "all.txt", header = TRUE, 
                   dec = ".", stringsAsFactors=T)

str(toad, vec.len = 2)

table(toad$hab)
# Some imbalance

#Drop habitats "A" and "B"
toad1 <- toad [-which(toad$hab == "A"), ]
toadx <- toad1 [-which(toad1$hab == "B"), ]
toad3 <- droplevels(toadx)
table(toad3$hab)

dim(toad) - dim(toad3)
#21 rows dropped

Toad <- toad3

# What is the percentage of zeros in the response variable
round(sum(toad$dist == 0) * 100 / nrow(toad),0)
#16% - rather high

# Standardise covariates
Toad$prec.std <- (Toad$prec-mean(Toad$prec))/sd(Toad$prec)
Toad$WC.std   <- (Toad$WC-mean(Toad$WC))/sd(Toad$WC)
Toad$RH.std   <- (Toad$RH-mean(Toad$RH))/sd(Toad$RH)
Toad$HI.std   <- (Toad$HI-mean(Toad$HI))/sd(Toad$HI)
Toad$BP.std   <- (Toad$BP-mean(Toad$BP))/sd(Toad$BP)
Toad$WS.std   <- (Toad$WS-mean(Toad$WS))/sd(Toad$WS)
Toad$TP.std   <- (Toad$TP-mean(Toad$TP))/sd(Toad$TP)

head(Toad)
dim(Toad)

#Fit zero-adjusted model
#Create zero-truncated dataframe: Toadz
#Derive PC for environmental variables

#Derive PCs
toad.pca <- prcomp(Toad[,c(8:13)], center = TRUE, scale. = TRUE)

#Examine PCA object
summary(toad.pca)

#Load coefficients for PC1
options(digits=4)
toad.pca$rotation[,1]

#And PC2
toad.pca$rotation[,2]

#PCA plot
ggbiplot(toad.pca, 
         obs.scale = 1,
         var.scale = 1,
         alpha = 1,
         varname.size = 4,
         varname.adjust = 2.6) +
  theme(text = element_text(size=13)) +
  theme(panel.background = element_blank()) +
  theme(panel.border = element_rect(fill = NA,
                       colour = "black", linewidth = 1))

Toad$PC1 <- toad.pca$x[,1]
Toad$PC2 <- toad.pca$x[,2]

# PC plot
ggplot(Toad, aes(x=PC2, y=PC1, size=dist, col=as.factor(sex), shape=as.factor(seas))) +
  geom_jitter(data = Toad, position = position_jitter
              (width = 0.5, height = 0.5), alpha = 0.8) +
  scale_colour_manual(values=c("red3", "blue2")) +
  labs(x="PC1 (61% explained variance)", 
       y="PC2 (20% explained variance)", 
       size="Distance moved (m)", 
       col="Sex", shape="Season") +
  theme(text = element_text(size=13)) +
  theme(panel.background = element_blank()) + 
  theme(panel.border = element_rect(fill = NA, colour = "black", size = 1)) +
  theme(strip.background = element_rect(fill = "white", 
                                        color = "white", size = 1))

#1. Fit Bernoulli GLMM
#2. Fit Gamma GLMM

# 1. Bernoulli GLMM
Bern1 <- glmer(act ~ sex + hab + seas + prec.std + PC1 + PC2 +
                    (1|ind),
                     family = binomial(link = "logit"),
                     data = Toad)

# MODEL VALIDATION

#Obtain residuals and fitted values
Res <- resid(Bern1)
Fit <- fitted(Bern1)

# Plot residuals against fitted values
par(mfrow = c(1,1), mar = c(5,5,2,2))
plot(x = Fit,
     y = Res,
     xlab = "Fitted values",
     ylab = "Residuals",
     pch = 16, cex = 1.5)
abline(h = 0, lty = 2)
#Fine

summary(Bern1)


######################################

# Define preferred figure format
My_theme <- theme(panel.background = element_blank(),
                  panel.border = element_rect(fill = NA, linewidth = 1),
                  strip.background = element_rect(fill = "white", 
                                                  color = "white", linewidth = 1),
                  text = element_text(size = 12),
                  panel.grid.major = element_line(colour = "white", linewidth = 0.1),
                  panel.grid.minor = element_line(colour = "white", linewidth = 0.1))

plot_model(Bern1, type = "eff", 
           terms = c("PC2[all]","seas"),
           colors = c("mediumblue","red2","green3"),
           show.data = TRUE,
           jitter = 0.02,
           title = "", 
           axis.title = c("PC2",
                          "Probability of movement"),
           show.legend = TRUE,
           legend.title = ("Season")) + 
  My_theme

##############################
# Zero-truncated data
#Drop zeros
Toad1 <- Toad [which(Toad$act == "1"), ]
Toadz <- droplevels(Toad1)
table(Toad$act)
table(Toadz$act)

#Balance of categories
table(Toadz$sex)
# F   M 
# 210 135 

table(Toadz$hab)
#   C   D 
# 256  89 

table(Toadz$seas)
# dry wet 
# 159 186 

# 2. Gamma GLMM
Gamma1 <- glmer(dist ~ sex * seas + prec.std + hab * PC1 + PC2 +
                      (1|ind),
                       family = Gamma(link = "log"),
                       data = Toadz)

# MODEL VALIDATION

#Obtain residuals and fitted values
Res <- resid(Gamma1)
Fit <- fitted(Gamma1)

# Plot residuals against fitted values
par(mfrow = c(1,1), mar = c(5,5,2,2))
plot(x = Fit,
     y = Res,
     xlab = "Fitted values",
     ylab = "Residuals",
     pch = 16, cex = 1.5)
abline(h = 0, lty = 2)
#Fine

summary(Gamma1)

tab_model(Bern1, Gamma1, 
          collapse.ci = FALSE,
          pred.labels = c("Intercept", "Sex (male)", "Habitat (mud)", 
                          "Season (wet)", "Precipitation","PC1", "PC2",
                          "Sex x Season", "Habitat x PC1"),
          dv.labels = c("Bernoulli model", "Gamma model"),
          string.pred = "Coeffcient",
          string.ci = "CI (95%)",
          string.p = "P")


#Plot model hab vs. PC1
plot_model(Gamma1, type = "eff", 
           terms = c("PC1[all]","hab"),
           colors = c("mediumblue","red2","green3"),
           show.data = TRUE,
           jitter = 0.02,
           title = "", 
           axis.title = c("PC2",
                          "Distance moved"),
           show.legend = TRUE,
           legend.title = ("Habitat")) + 
  My_theme

# === hic est finis ===

