########################################################################

# Analysis for reflector type data

########################################################################

library(arm)
library(car)
library(effects)
library(ggplot2)
library(GGally)
library(lattice)
library(lawstat)
library(outliers)
library(tidyverse)
library(rlang)
library(gridExtra)
library(glmmTMB)
library(tidyverse)
library(DHARMa)
library(AICcmodavg)
library(performance)
library(ggpubr)
library(sjPlot)
library(sjmisc)
library(sjlabelled)

#=======================================

# Import the data
ref <- read.table(file = "reflectortype.txt", header = TRUE, 
                   dec = ".", stringsAsFactors=T)

# Start by inspecting dataframe:
str(ref, vec.len = 2)

# Are there missing values?
colSums(is.na(ref))

# For clarity, rename the two levels of 'sex'
ref$fSex <- dplyr::recode(ref$Sex, 
                           "F" = "Female", 
                           "M" = "Male")
str(ref, vec.len = 2)

# HOUSEKEEPING

# Define preferred figure format
My_theme <- theme(panel.background = element_blank(),
                  panel.border = element_rect(fill = NA, linewidth = 1),
                  strip.background = element_rect(fill = "white", 
                                                  color = "white", linewidth = 1),
                  text = element_text(size = 12),
                  panel.grid.major = element_line(colour = "white", linewidth = 0.1),
                  panel.grid.minor = element_line(colour = "white", linewidth = 0.1))

# A function for dotplots
multi_dotplot <- function(filename, Xvar, Yvar){
  filename %>%
    ggplot(aes(x = {{Xvar}})) +
    geom_point(aes(y = {{Yvar}})) +
    My_theme +
    coord_flip() +
    labs(x = "Order of Data")}

# Examine variance of factors using boxplots
ref %>%
  ggplot(aes(y = Adist, x = fSex)) +
  labs(y = "Distance moved", 
       x = "Sex") +
  geom_boxplot(fill = "gray88", outlier.shape = 19) +
  My_theme

ref %>%
  ggplot(aes(y = Adist, x = type)) +
  labs(y = "Distance moved", 
       x = "Sex") +
  geom_boxplot(fill = "gray88", outlier.shape = 19) +
  My_theme

#Order data
ref <- ref %>%
  mutate(order = seq(1:nrow(ref)))

#Select continuous variables to plot
p1 <- multi_dotplot(ref, order, Adist)
p2 <- multi_dotplot(ref, order, Weight)
p3 <- multi_dotplot(ref, order, SVL)

#Plot as a grid
grid.arrange(p1, p2, p3, nrow = 1)

# Frequency polygon plot for toad species size
ref %>% ggplot(aes(Adist)) +
  geom_freqpoly(bins = 8) +
  labs(x = "Distance", y = "Frequency") +
  My_theme

# Balance of categorical variable

# Sex
table(ref$fSex)
# Female   Male 
# 20     30

table(ref$type)
# Diode Recco 
# 30    20  

# What is the percentage of zeros in the response variable
round(sum(ref$Adist == 0) * 100 / nrow(ref),0)
#10%

# Obtain summary using the ggpairs command from the GGally library
ref %>% 
  ggpairs(columns = c("fSex","type","Weight","SVL"), aes(alpha = 0.8), 
          lower = list(combo = wrap("facethist", binwidth = 2))) + 
  My_theme
#Weight & SVL correlated

# Relationships among response and independent variables
ggplot(ref, aes(x = Weight, y = (Adist))) +
  geom_jitter(shape = 16, size = 5, alpha = 0.5, height = 0.5, width = 0.25) +
  geom_smooth(formula = y ~ x, method = 'lm', 
              colour = 'red', se = FALSE, linewidth = 1.5) +
  My_theme +
  xlab("Weight") + ylab("Distance") +
  facet_grid(.~fSex)
  # facet_grid(.~type)
# No obvious interaction

# Independence of the response variable?
table(ref$individual)
# OK

# Fit Gaussian LM
M1 <- glmmTMB(Adist ~ fSex + type + Weight,
                      data = ref)

# Plot residuals against fitted values
# Simulate data using model parameters
Res1 <- simulateResiduals(fittedModel = M1, plot = F)

# Plot standardised residuals
par(mfrow = c(1,1), mar = c(5,5,4,4))
plotResiduals(Res1)
# Fine

# Plot model residuals against covariates in the model
par(mfrow = c(2,2), mar = c(5,5,4,4))
plotResiduals(Res1, form = ref$Weight)
plotResiduals(Res1, form = ref$fSex)
plotResiduals(Res1, form = ref$type)

# And not included in the model
plotResiduals(Res1, form = ref$SVL)
# Fine

# Check normality of residuals, dispersion and presence of outliers
par(mfrow = c(1,1), mar = c(5,5,2,2))
plotQQunif(Res1, testOutliers = TRUE, testDispersion = TRUE)
# Fine

# Obtain model output with:
summary(M1)

#                Estimate Std. Error z value Pr(>|z|)    
# (Intercept)   -0.520      1.151   -0.45    0.651  
# fSexMale       0.232      0.551    0.42    0.673  
# typeRecco      0.300      0.343    0.88    0.381 <-no effect of reflector type
# Weight         1.913      0.974    1.96    0.049

# And as a neat table:
tab_model(M1,
          show.zeroinf = TRUE,
          dv.labels = c("GLM (reflector)"),
          string.pred = "Coefficient",
          # pred.labels = c("Intercept", "Sex(male)",
          #                 "Reflector(Recco)",
          #                 "Weight"),
          string.ci = "Conf. Int (95%)",
          collapse.ci = FALSE,
          auto.label = FALSE,
          string.p = "P-value",
          p.style = c("numeric"),
          emph.p = FALSE,
          transform = NULL)


# VISUALISE THE RESULTS
plot_model(M1, type = "eff", 
           terms = c("Weight","fSex","type"),
           colors = c("mediumblue","red2","green3"),
           show.data = TRUE,
           jitter = 0.02,
           title = "", 
           axis.title = c("Weight (g)",
                          "Distance moved (m)"),
           show.legend = TRUE,
           legend.title = ("Sex")) + 
  scale_y_continuous(limits = c(-1, 6)) +
  My_theme

# === hic est finis ===


