########################################################################

# Analysis for reflector weight data

########################################################################
#Load packages

library(arm)
library(car)
library(effects)
library(ggplot2)
library(GGally)
library(lattice)
library(lawstat)
library(outliers)
library(tidyverse)
library(rlang)
library(gridExtra)
library(glmmTMB)
library(tidyverse)
library(DHARMa)
library(AICcmodavg)
library(performance)
library(ggpubr)
library(sjPlot)
library(sjmisc)
library(sjlabelled)
######################################

#Import the file into a dataframe
toad <- read.table(file = "sexdiff.txt", header = TRUE, 
                   dec = ".", stringsAsFactors=T)

#Inspect dataframe
str(toad)

# 'data.frame':	89 obs. of  12 variables:
# $ individual: Factor w/ 89 levels "OQ001","OQ002",..: 1 2 3 4 5 6 7 8 9 10 ...
# $ Sex       : Factor w/ 2 levels "F","M": 1 1 2 2 2 1 1 2 1 2 ...
# $ Seas      : Factor w/ 2 levels "dry","wet": 2 2 2 2 2 2 2 2 2 2 ...
# $ NumMov    : int  11 9 7 6 5 5 18 7 9 6 ...
# $ Weight    : num  1.17 0.92 0.74 0.5 0.82 1.15 1.29 0.62 0.97 0.44 ...
# $ SVL       : num  22.9 22.7 21 19 21.5 25 27 20.2 23 18 ...
# $ Tdist     : num  10.3 10.95 4.6 1.4 6.92 ...
# $ Adist     : num  0.94 1.22 0.66 0.23 1.38 0.98 0.72 0.63 0.53 0.08 ...
# $ Daydist   : num  1.03 1.37 0.77 0.64 1.73 1.23 0.76 0.73 0.53 0.1 ...
# $ Min       : num  0.1 0 0 0.2 0.92 0.4 0 0.03 0 0 ...
# $ Max       : num  4 6 4 2 2.3 2.7 2.1 2.3 1.8 0.5 ...
# $ Disp      : num  8.32 3.37 4.06 1.27 2.72 4.06 1.45 1.87 3.8 0.44 ...

# For clarity, let's rename the two levels of 'status'
toad$fSex <- dplyr::recode(toad$Sex, 
                           "F" = "Female", 
                           "M" = "Male")

toad$fSeas <- dplyr::recode(toad$Seas, 
                           "dry" = "Dry season", 
                           "wet" = "Wet season")

# Assume an average reflector weight of 0.06 g

toad$refWt <- (0.06/toad$Weight)*100

######################################

# DATA EXPLORATION

# Are there missing values?
colSums(is.na(toad))

# individual        Sex       Seas     NumMov     Weight        SVL      Tdist      Adist    Daydist 
# 0          0          0          0          0          0          0          0          2 
# Min        Max       Disp 
# 2          2          0 
#A couple

# OUTLIERS

# A multi-panel Cleveland dotplot to see all variables simultaneously

# First make a vector of variables of interest
Var <- c("NumMov", "Weight", "SVL", "Tdist", "Adist", "Daydist", "Min", "Max", "Disp")

# Multi-panel dotchart
dotplot(as.matrix(as.matrix(toad[,Var])),
             groups=FALSE,
             strip = strip.custom(bg = 'white',
                                  par.strip.text = list(cex = 1.2)),
             scales = list(x = list(relation = "free", draw = TRUE),
                           y = list(relation = "free", draw = FALSE)),
             col = 1, cex = 1, pch = 16,
             xlab = list(label = "Data range", cex = 1.5),
             ylab = list(label = "Data order", cex = 1.5))
# One very high Disp, 2 high TAdist. a high Weight & SVL

######################################
#NORMALITY AND HOMOGENEITY OF DEPENDENT VARIABLE

#Frequency polygon plot
p <- ggplot()
p <- p + ylab("Frequency")
p <- p + xlab("Adistance moved (m)")
p <- p + theme(panel.background = element_blank())
p <- p + theme(panel.border = element_rect(fill = NA, 
                                           colour = "black", size = 1))
p <- p + theme(strip.background = element_rect(fill = "white", 
                                               color = "white", size = 1))
p <- p + theme(text = element_text(size=15))
p <- p + theme(legend.position='none')
p <- p + geom_freqpoly(data = toad, aes(Adist), bins = 12)
p
# Positive skew

# Homogeneity of variance

# Plot factors
par(mfrow = c(1,3), mar = c(5,5,2,2), cex.lab = 1.5)
boxplot(Adist ~ Sex,
        ylab = "Adist (m)",
        xlab = "Sex",
        pch = 16, cex = 1.5, col = "firebrick2",
        data = toad)

boxplot(Adist ~ Seas,
        ylab = "Adist (m)",
        xlab = "Season",
        pch = 16, cex = 1.5, col = "cadetblue",
        data = toad)

boxplot(Adist ~ individual,
        ylab = "Adist (m)",
        xlab = "individual",
        pch = 16, cex = 1.5, col = "forestgreen",
        data = toad)

#Some outliers, but otherwise homogenous

#Balance of categories
table(toad$fSex)
# F   M 
# 42 47  

table(toad$fSeas)
# dry wet 
# 50  39 

table(toad$individual)
# No pseudoreplication

#Plot coninuous variables
par(mfrow = c(2,2), mar = c(5,5,2,2), cex.lab = 1.5)
plot(x = toad$NumMov,
     y = toad$Adist,
     ylab = "Adist (m)",
     xlab = "NumMov",
     cex = 1.2, pch = 16)

plot(x = toad$Disp,
     y = toad$Adist,
     ylab = "Adist (m)",
     xlab = "Disp",
     cex = 1.2, pch = 16)

plot(x = toad$Weight,
     y = toad$Adist,
     ylab = "Adist (m)",
     xlab = "Weight",
     cex = 1.2, pch = 16)

plot(x = toad$SVL,
     y = toad$Adist,
     ylab = "Adist (m)",
     xlab = "SVL",
     cex = 1.2, pch = 16)


# What is the percentage of zeros for Adistance?

sum(toad$Adist == 0) * 100 / nrow(toad)
#8%


#COLLINEARITY

Coll <- c("Sex", "Seas", "Weight", "SVL", "NumMov", "Disp")

panel.cor <- function(x, y, digits=1, prefix="", cex.cor = 6)
{usr <- par("usr"); on.exit(par(usr))
par(usr = c(0, 1, 0, 1))
r1=cor(x,y,use="pairwise.complete.obs")
r <- abs(cor(x, y,use="pairwise.complete.obs"))
txt <- format(c(r1, 0.123456789), digits=digits)[1]
txt <- paste(prefix, txt, sep="")
if(missing(cex.cor)) { cex <- 0.9/strwidth(txt) } else {
  cex = cex.cor}
text(0.5, 0.5, txt, cex = cex * r)}
pairs(toad[, Coll], lower.panel = panel.cor)
#Problem of collinearity with Weight & SVL

#Calculate Variance Inflation Factor (VIF)
vif(lm(Adist ~ Sex + Seas + Weight + SVL + NumMov + Disp, data = toad))

# Sex     Seas   Weight      SVL   NumMov     Disp 
# 2.009739 1.381247 6.560827 5.913834 1.566953 1.320508 
# Drop SVL

vif(lm(Adist ~ Sex + Seas + Weight + NumMov + Disp, data = toad))

# Sex     Seas      SVL      NumMov    Disp 
# 1.863459 1.381247 2.029485 1.560701  1.233978 
# OK

#PLOT RELATIONSHIPS

# Any evidence of an interactions?
ggplot(toad) + 
  aes(x = Weight, y = Adist) + 
  stat_smooth(formula = y ~ x, method = "lm", 
              se = FALSE, colour="red", size=1) +
  labs(x = "Weight", y = "Adist") +
  theme(panel.background = element_blank()) +
  theme(panel.border = element_rect(fill = NA, 
                                    colour = "black", linewidth = 1)) +
  theme(strip.background = element_rect(fill = "white", 
                                        color = "white", linewidth = 1)) +
  theme(text = element_text(size=15)) +
  geom_point(size=2.5, alpha = 0.7) +
  facet_wrap("fSex")
# facet_wrap("Seas")

# Nothing obvious


# Deal with problematic outliers
toad1 <- toad[which(toad$Weight < 2),] #drop weight >2 g
toad2 <- toad1[which(toad1$Adist < 5),] #drop distand >5 m

# Original
plot(x = toad$Weight,
     y = toad$Adist,
     ylab = "Adist (m)",
     xlab = "Weight",
     cex = 1.2, pch = 16)
range(toad2$Adist)

# After dropping outliers
plot(x = toad2$Weight,
     y = toad2$Adist,
     ylab = "Adist (m)",
     xlab = "Weight",
     cex = 1.2, pch = 16)
range(toad2$Adist)
# OK

# Start with Gaussian GLMM
gaus1 <- glmmTMB(Adist ~ Weight + Sex + fSeas * refWt,
                 family = gaussian(link = "identity"),
                 data = toad2)


#Obtain residuals and fitted values
Res <- resid(gaus1)
Fit <- fitted(gaus1)

# Plot residuals against fitted values
par(mfrow = c(1,1), mar = c(5,5,2,2))
plot(x = Fit,
     y = Res,
     xlab = "Fitted values",
     ylab = "Residuals",
     pch = 16, cex = 1.5)
abline(h = 0, lty = 2)
#OK

#Normality of residuals
shapiro.test(Res)
#No significant departure from normality

# Define preferred figure format
My_theme <- theme(panel.background = element_blank(),
                  panel.border = element_rect(fill = NA, linewidth = 1),
                  strip.background = element_rect(fill = "white", 
                                                  color = "white", linewidth = 1),
                  text = element_text(size = 12),
                  panel.grid.major = element_line(colour = "white", linewidth = 0.1),
                  panel.grid.minor = element_line(colour = "white", linewidth = 0.1))

# Plot model
plot_model(gaus1, type = "eff", 
           terms = c("refWt[all]","fSeas"),
           colors = c("mediumblue","red2","green3"),
           show.data = TRUE,
           jitter = 0.02,
           title = "", 
           axis.title = c("Relative reflector weight (%)",
                          "Distance moved (m)"),
           show.legend = TRUE,
           legend.title = ("Season")) + 
           My_theme

tab_model(gaus1, 
          collapse.ci = FALSE,
          pred.labels = c("Intercept", "Weight", "Sex (male)", "Season (wet)", 
                          "Relative weight", "Season (wet):Relative weight"),
          dv.labels = c("Gaussian GLM"),
          string.pred = "Coefficient",
          string.ci = "CI (95%)",
          string.p = "P")

# === hic est finis ===
